@@ -41,6 +41,7 @@ import warnings
 
 import anyjson
 from restkit.util import url_quote
+from restkit.util.misc import deprecated_property
 
 from couchdbkit.exceptions import *
 import couchdbkit.resource as resource
@@ -82,7 +83,7 @@ class Server(object):
 
         if resource_instance and isinstance(resource_instance, 
                                 resource.CouchdbResource):
-            resource_instance.uri = uri
+            resource_instance.initial['uri'] = uri
             self.res = resource_instance.clone()
             if pool_instance is not None:
                 self.res.client_opts['pool_instance'] = pool_instance
@@ -286,11 +287,13 @@ class Database(object):
         path = "/_compact"
         if dname is not None:
             path = "%s/%s" % (path, resource.escape_docid(dname))
-        res = self.res.post(path)
+        res = self.res.post(path, headers={"Content-Type": 
+            "application/json"})
         return res.json_body
 
     def view_cleanup(self):
-        res = self.res.post('/_view_cleanup')
+        res = self.res.post('/_view_cleanup', headers={"Content-Type":
+            "application/json"})
         return res.json_body
 
     def flush(self):
@@ -387,7 +390,7 @@ class Database(object):
 
         return self.view('_all_docs', _raw_json=_raw_json, **params)
 
-    def doc_revisions(self, docid, with_doc=True, _raw_json=False):
+    def _doc_revisions(self, docid, with_doc=True, _raw_json=False):
         """ retrieve revisions of a doc
 
         @param docid: str, id of document
@@ -424,6 +427,10 @@ class Database(object):
             return None
         return doc_with_revs
 
+    doc_revisions = deprecated_property(_doc_revisions,
+            "_doc_revisions", "doc_revisions is deprecated use "
+            "Database.open_docs with the right parameters", False)
+
     def get_rev(self, docid):
         """ Get last revision from docid (the '_rev' member)
         @param docid: str, undecoded document id.
@@ -796,7 +803,8 @@ class Database(object):
 
     def ensure_full_commit(self, _raw_json=False):
         """ commit all docs in memory """
-        return maybe_raw(self.res.post('_ensure_full_commit'), raw=_raw_json)
+        return maybe_raw(self.res.post('_ensure_full_commit', 
+            headers={"Content-Type": "application/json"}), raw=_raw_json)
 
     def __len__(self):
         return self.info()['doc_count']
