@@ -393,7 +393,7 @@ class FileSystemDocsLoader(BaseDocsLoader):
                 except UnicodeDecodeError, e:
                     if verbose >= 2:
                         print >>sys.stderr, "%s isn't encoded in utf8" % current_path
-                    content = self.ui.read(current_path, utf8=False)
+                    content = read_file(current_path, utf8=False)
                     try:
                         content.encode('utf-8')
                     except UnicodeError, e:
@@ -431,7 +431,7 @@ class FileSystemDocsLoader(BaseDocsLoader):
             if os.path.isdir(current_path):
                 attach_dir = os.path.join(current_path, '_attachments')
                 if os.path.isdir(attach_dir):
-                    self.push_directory(design_doc, attach_dir, docid, verbose, 
+                    self.attach(design_doc, attach_dir, docid, verbose, 
                                     vendor=name)
 
     def attach(self, doc, attach_dir, docid, verbose=False, vendor=None):
