@@ -53,9 +53,9 @@ class CouchDBResponse(HttpResponse):
     @property
     def json_body(self):
         try:
-            return anyjson.deserialize(self.body)
+            return anyjson.deserialize(self.body_string())
         except ValueError:
-            return self.body
+            return self.body_string()
 
 
 class CouchdbResource(Resource):
@@ -161,6 +161,9 @@ def encode_params(params):
     _params = {}
     if params:
         for name, value in params.items():
+            if value is None:
+                continue
+            
             if name in ('key', 'startkey', 'endkey') \
                     or not isinstance(value, basestring):
                 value = anyjson.serialize(value)
