@@ -1,18 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -
 #
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com> 
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 #
 __author__ = 'benoitc@e-engura.com (Benoît Chesneau)'
 
@@ -24,10 +13,13 @@ ResourceConflict
 
 from couchdbkit import *
 
+from restkit import SimplePool
+pool = SimplePool()
+
 class ClientServerTestCase(unittest.TestCase):
     def setUp(self):
         self.couchdb = CouchdbResource()
-        self.Server = Server()
+        self.Server = Server(pool_instance=pool)
         
     def tearDown(self):
         try:
@@ -35,6 +27,7 @@ class ClientServerTestCase(unittest.TestCase):
             del self.Server['couchdbkit/test']
         except:
             pass
+        self.Server.close()
 
     def testGetInfo(self):
         info = self.Server.info()
@@ -215,10 +208,10 @@ class ClientDatabaseTestCase(unittest.TestCase):
         self.assert_( "a/b" in db) 
         self.assert_( "http://a" in db)
         self.assert_( "_design/a" in db)
+
         def not_found():
             doc = db.get('http:%2F%2Fa')
         self.assertRaises(ResourceNotFound, not_found)
-        del self.Server['couchdbkit_test']
 
     def testFlush(self):
         db = self.Server.create_db('couchdbkit_test')
@@ -631,27 +624,6 @@ class ClientViewTestCase(unittest.TestCase):
 
         del self.Server['couchdbkit_test']
 
-    def testAllDocsBySeq(self):
-        db = self.Server.create_db('couchdbkit_test')
-        # save 2 docs 
-        doc1 = { '_id': 'test', 'string': 'test', 'number': 4, 
-                'docType': 'test' }
-        db.save_doc(doc1)
-        doc2 = { '_id': 'test2', 'string': 'test', 'number': 2,
-                    'docType': 'test'}
-        db.save_doc(doc2)
-        
-        self.assert_(db.view('_all_docs_by_seq').count() == 2 )
-        self.assert_(db.view('_all_docs_by_seq').all() == db.all_docs(by_seq=True).all())
-        results = db.all_docs(by_seq=True).all()
-        self.assert_(sorted([i["id"] for i in results]) == ["test", "test2"])
-        self.assert_(sorted([i["key"] for i in results]) == [1,2])
-
-        del self.Server['couchdbkit_test']
-
-
-
-
     def testCount(self):
         db = self.Server.create_db('couchdbkit_test')
         # save 2 docs 
